Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
commiteaf1cdd3836aa425e3dc6f1a11d4556bd7e3e876 (patch)
treefe8e701c3e3daa38749b78238858edbbbfea1f91 /source/blender/python/api2_2x/Bone.h
parent569a32a2ea3a1992eaeaa5dc0256c48e8a053fbd (diff)
- More renaming all around to follow our conventions
- Implemented partially Blender.Sys - Worked on issues related to sys, path - Took away most "debug" printfs
Diffstat (limited to 'source/blender/python/api2_2x/Bone.h')
-rw-r--r--source/blender/python/api2_2x/Bone.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/python/api2_2x/Bone.h b/source/blender/python/api2_2x/Bone.h
index ec71a8f33df..762733b47fc 100644
--- a/source/blender/python/api2_2x/Bone.h
+++ b/source/blender/python/api2_2x/Bone.h
@@ -37,18 +37,18 @@
#include <DNA_armature_types.h>
/** Bone module initialization function. */
-PyObject *M_Bone_Init (void);
+PyObject *Bone_Init (void);
-/** Python C_Bone structure definition. */
+/** Python BPy_Bone structure definition. */
typedef struct {
PyObject_HEAD
Bone *bone;
-} C_Bone;
+} BPy_Bone;
-PyObject* M_BoneCreatePyObject (struct Bone *obj);
-int M_BoneCheckPyObject (PyObject *py_obj);
-Bone* M_BoneFromPyObject (PyObject *py_obj);
+PyObject* Bone_CreatePyObject (struct Bone *obj);
+int Bone_CheckPyObject (PyObject *py_obj);
+Bone* Bone_FromPyObject (PyObject *py_obj);
#endif